@@ -3,8 +3,6 @@ from collections import defaultdict
 import django
 
 
-
-
 # this default dict will store all compat quirks for parameters of
 # django.contrib.auth views
 auth_views_compat_quirks = defaultdict(lambda: dict())
@@ -29,4 +27,18 @@ if django.VERSION >= (1, 6, 0):
 password_reset_uid_kwarg = 'uidb64'
 if django.VERSION < (1, 6, 0):
     # Django<1.6.0 uses uidb36, we construct urlpattern depending on this
-    password_reset_uid_kwarg = 'uidb36'
\ No newline at end of file
+    password_reset_uid_kwarg = 'uidb36'
+
+
+# SiteProfileNotAvailable compatibility
+if django.VERSION < (1, 7, 0):
+    from django.contrib.auth.models import SiteProfileNotAvailable
+else:
+    class SiteProfileNotAvailable(Exception):
+        pass
+
+# old fallback to django hashcompat
+try:
+    from hashlib import sha1 as sha_constructor, md5 as md5_constructor
+except ImportError:
+    from django.utils.hashcompat import sha_constructor, md5_constructor
\ No newline at end of file
