@@ -1,13 +1,9 @@
 from django.conf import settings
-from django.contrib.auth.models import SiteProfileNotAvailable
 from django.db.models import get_model
 
-try:
-    from hashlib import sha1 as sha_constructor, md5 as md5_constructor
-except ImportError:
-    from django.utils.hashcompat import sha_constructor, md5_constructor
-
 from userena import settings as userena_settings
+from userena.compat import SiteProfileNotAvailable
+from userena.compat import sha_constructor, md5_constructor
 
 import urllib, random, datetime
 
@@ -128,11 +124,29 @@ def get_profile_model():
            (not settings.AUTH_PROFILE_MODULE):
         raise SiteProfileNotAvailable
 
-    profile_mod = get_model(*settings.AUTH_PROFILE_MODULE.rsplit('.',1))
+    try:
+        profile_mod = get_model(*settings.AUTH_PROFILE_MODULE.rsplit('.', 1))
+    except LookupError:
+        profile_mod = None
+
     if profile_mod is None:
         raise SiteProfileNotAvailable
     return profile_mod
 
+def get_user_profile(user):
+    profile_model = get_profile_model()
+    try:
+        profile = user.get_profile()
+    except AttributeError:
+        related_name = profile_model._meta.get_field_by_name('user')[0]\
+                                    .related_query_name()
+        profile = getattr(user, related_name, None)
+    except profile_model.DoesNotExist:
+        profile = None
+    if profile:
+        return profile
+    return profile_model.objects.create(user=user)
+
 def get_protocol():
     """
     Returns a string with the current protocol.
@@ -172,5 +186,5 @@ user_model_label = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 try:
     from django.contrib.auth import get_user_model
 except ImportError:
-    from django.contrib.auth.models import User
-    get_user_model = lambda: User
+    def get_user_model():
+        return get_model(*user_model_label.rsplit('.', 1))
